Method: Sass.load_paths

Defined in:
lib/sass.rb

.load_pathsArray<String, Pathname, Sass::Importers::Base>

The global load paths for Sass files. This is meant for plugins and libraries to register the paths to their Sass stylesheets to that they may be @imported. This load path is used by every instance of Engine. They are lower-precedence than any load paths passed in via the :load_paths option.

If the SASS_PATH environment variable is set, the initial value of load_paths will be initialized based on that. The variable should be a colon-separated list of path names (semicolon-separated on Windows).

Note that files on the global load path are never compiled to CSS themselves, even if they aren't partials. They exist only to be imported.

Examples:

Sass.load_paths << File.dirname(__FILE__ + '/sass')

Returns:



37
38
39
40
41
42
43
# File 'lib/sass.rb', line 37

def self.load_paths
  @load_paths ||= if ENV['SASS_PATH']
                    ENV['SASS_PATH'].split(Sass::Util.windows? ? ';' : ':')
                  else
                    []
                  end
end