Method: Sass::Script::Tree::Interpolation#deprecation

Defined in:
lib/sass/script/tree/interpolation.rb

#deprecationSymbol (readonly)

The type of interpolation deprecation for this node.

This can be :none, indicating that the node doesn't use deprecated interpolation; :immediate, indicating that a deprecation warning should be emitted as soon as possible; or :potential, indicating that a deprecation warning should be emitted if the resulting string is used in a way that would distinguish it from a list.

Returns:

  • (Symbol)


39
40
41
# File 'lib/sass/script/tree/interpolation.rb', line 39

def deprecation
  @deprecation
end