Method: Sass::Script::Tree::Interpolation#originally_text

Defined in:
lib/sass/script/tree/interpolation.rb

#originally_textBoolean (readonly)

Returns Whether the original format of the interpolation was plain text, not an interpolation. This is used when converting back to SassScript.

Returns:

  • (Boolean)

    Whether the original format of the interpolation was plain text, not an interpolation. This is used when converting back to SassScript.



24
25
26
# File 'lib/sass/script/tree/interpolation.rb', line 24

def originally_text
  @originally_text
end