Method: Sass::Script::Tree::Interpolation#warn_for_color

Defined in:
lib/sass/script/tree/interpolation.rb

#warn_for_colorBoolean (readonly)

Returns Whether a color value passed to the interpolation should generate a warning.

Returns:

  • (Boolean)

    Whether a color value passed to the interpolation should generate a warning.



28
29
30
# File 'lib/sass/script/tree/interpolation.rb', line 28

def warn_for_color
  @warn_for_color
end