Method: Sass::Script::Tree::MapLiteral#pairs

Defined in:
lib/sass/script/tree/map_literal.rb

#pairsArray<(Node, Node)> (readonly)

The key/value pairs that make up this map node. This isn't a Hash so that we can detect key collisions once all the keys have been performed.

Returns:



9
10
11
# File 'lib/sass/script/tree/map_literal.rb', line 9

def pairs
  @pairs
end