Method: Sass::Script::Value::Color#hsl

Defined in:
lib/sass/script/value/color.rb

#hslArray<Integer>

Returns the hue, saturation, and lightness components of the color.

Returns:

  • (Array<Integer>)

    A frozen three-element array of the hue, saturation, and lightness values (respectively) of the color



379
380
381
# File 'lib/sass/script/value/color.rb', line 379

def hsl
  [hue, saturation, lightness].freeze
end