Method: Sass::Script::Value::Color#rgb

Defined in:
lib/sass/script/value/color.rb

#rgbArray<Integer>

Returns the red, green, and blue components of the color.

Returns:

  • (Array<Integer>)

    A frozen three-element array of the red, green, and blue values (respectively) of the color



363
364
365
# File 'lib/sass/script/value/color.rb', line 363

def rgb
  [red, green, blue].freeze
end