The second splat argument for this function, if one exists.
If this exists, it's always a map of keyword arguments, and #splat is always either a list or an arglist.
Returns:
45 46 47
# File 'lib/sass/script/tree/funcall.rb', line 45 def kwarg_splat @kwarg_splat end